@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate.py 10200 2017-08-20 02:49:07Z Lavender $
+# $Id: build_boilerplate.py 10213 2017-08-22 09:34:20Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
-# $Revision: 10200 $
+# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
+# $Revision: 10213 $
 
 import os
 import sys
@@ -28,9 +28,9 @@ from django.template.loader import get_template
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import cerateLogger
+from Zephyrus.boilerplate.management.commands import createLogger
 
-logger = cerateLogger(__name__, "BuildBoilerplate.log")
+logger = createLogger(__name__, "BuildBoilerplate.log")
 
 # inside
 TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'button',]
