@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 9919 2017-04-27 07:05:09Z Lavender $
+# $Id: models.py 10219 2017-08-27 05:13:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,17 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-27 15:05:09 +0800 (週四, 27 四月 2017) $
-# $Revision: 9919 $
+# $Date: 2017-08-27 13:13:34 +0800 (週日, 27 八月 2017) $
+# $Revision: 10219 $
 
 from django.db import models
 from django.utils import timezone
+from jsonfield import JSONField
 
 class Email(models.Model):
     email = models.EmailField()
     fromUrl = models.URLField()
     date = models.DateTimeField(
         auto_now_add=True)
+
+    data = JSONField(null=True, blank=True, default={})
         
     def __unicode__(self):
         return u"%s From: %s (%s)" % (self.email, self.fromUrl, self.date)
